jacinle.comm.gather
===================

.. automodule:: jacinle.comm.gather

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      GatherInputPipe
      GatherOutputPipe
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      make_gather_pair
   
   

   
   
   








.. rubric:: Class GatherInputPipe
.. autoclass:: GatherInputPipe
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class GatherOutputPipe
.. autoclass:: GatherOutputPipe
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: make_gather_pair


